@@ -727,11 +727,11 @@ sub gen_url{
 sub gen_response{
     my ($self) = shift;
     my $ua = LWP::UserAgent->new();
-    $ua->get($self->url);
+    my $ua_res = $ua->get($self->url);
 
     #json
     if($self->xml_json =~ /json/i){
-        my $obj = from_json($ua->content);
+        my $obj = from_json($ua_res->decoded_content);
         my $json = JSON->new->pretty(1)->encode($obj);
         $self->response("$json");
     }
@@ -740,7 +740,7 @@ sub gen_response{
     else{
         my $parser = XML::Simple->new;
 
-        my $xml = encode('utf8',$ua->content);#cp932 for Win
+        my $xml = encode('utf8',$ua_res->decoded_content);#Please Change cp932 for Win.
         my $twig = XML::Twig->new(pretty_print => 'indented', );
         $twig->parse($xml);
 
@@ -757,11 +757,11 @@ Net::CloudStack - Bindings for the CloudStack API
 
 =head1 VERSION
 
-Version 0.00006
+Version 0.00007
 
 =cut
 
-our $VERSION = '0.00006';
+our $VERSION = '0.00007';
 
 
 =head1 SYNOPSIS
